package cn.superdesk.data.extract.job.flsc;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.thread.ThreadUtil;
import cn.superdesk.data.extract.dto.JobParamDTO;
import cn.superdesk.data.extract.entity.flsc.FlscShopOrder;
import cn.superdesk.data.extract.entity.opCenter.OperationCenterOrder;
import cn.superdesk.data.extract.entity.opCenter.OperationCenterOrderGoods;
import cn.superdesk.data.extract.entity.opCenter.OperationDataSyncErrorRecord;
import cn.superdesk.data.extract.enums.OpCenterJobSyncTypeEnum;
import cn.superdesk.data.extract.enums.opCenter.*;
import cn.superdesk.data.extract.mapper.flsc.FlscShopOrderMapper;
import cn.superdesk.data.extract.mapper.opCenter.OperationCenterOrderGoodsMapper;
import cn.superdesk.data.extract.mapper.opCenter.OperationCenterOrderMapper;
import cn.superdesk.data.extract.service.flsc.FlscShopOrderService;
import cn.superdesk.data.extract.service.opCenter.OperationDataSyncErrorRecordService;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author xc
 * @description 福利商城正单数据同步 & 运费商品构造
 * @date 2023/3/27 10:35
 */
@Component
@Slf4j
@RequiredArgsConstructor
public class FlscOrderSyncJob {

    private final FlscShopOrderMapper flscShopOrderMapper;
    private final FlscShopOrderService flscShopOrderService;
    private final OperationCenterOrderMapper operationCenterOrderMapper;
    private final OperationCenterOrderGoodsMapper operationCenterOrderGoodsMapper;
    private final OperationDataSyncErrorRecordService operationDataSyncErrorRecordService;


    /**
     * 福利商城正单数据同步 & 运费商品构造
     */
    @XxlJob("flscOrderSyncHandler")
    @Transactional(rollbackFor = Exception.class)
    public void flscOrderSync() {
        String startTime = DateUtil.now();
        String jobParam = XxlJobHelper.getJobParam();
        log.info("任务参数 : {}", jobParam);
        XxlJobHelper.log("任务参数 : {}", jobParam);
        // 解析参数
        JobParamDTO jobParamDTO = null;

        // 福利商城订单列表
        List<FlscShopOrder> flscShopOrderList;
        // 变动数据总数
        Integer total = 0;
        // 同步类型
        int syncType;
        // 数据查询参数
        Object syncParam;
        if (StringUtils.isNotBlank(jobParam)) {
            try {
                jobParamDTO = JSON.parseObject(jobParam, JobParamDTO.class);
            } catch (Exception e) {
                log.info("任务参数解析异常", e);
                XxlJobHelper.log("任务参数解析异常", e);
                throw new RuntimeException("任务参数解析异常");
            }
            if (jobParamDTO == null || (StringUtils.isBlank(jobParamDTO.getMainParam()) && StringUtils.isBlank(jobParamDTO.getSyncTime()))) {
                log.info("任务参数解析失败 参数内容: {}", jobParam);
                XxlJobHelper.log("任务参数解析失败 参数内容: {}", jobParam);
                throw new RuntimeException("任务参数解析失败");
            }

            String syncTime = jobParamDTO.getSyncTime();
            String mainParam = jobParamDTO.getMainParam();
            if (StringUtils.isNotBlank(syncTime)) {
                // 按照指定时间同步
                try {
                    syncParam = DateUtil.parse(syncTime);
                } catch (Exception e) {
                    log.info("任务参数解析异常, 参数内容: {}", jobParam);
                    XxlJobHelper.log("任务参数解析异常, 参数内容 : {}", jobParam);
                    throw new RuntimeException("任务参数解析异常");
                }
                // 数据变化量
                total = flscShopOrderMapper.selectCount(
                        Wrappers.<FlscShopOrder>lambdaQuery()
                                .ge(FlscShopOrder::getSyncTime, syncParam)
                );
                syncType = OpCenterJobSyncTypeEnum.按照指定时间同步.getCode();

            } else {

                // 数据变化量
                total = flscShopOrderMapper.selectCount(
                        Wrappers.<FlscShopOrder>lambdaQuery()
                                .eq(FlscShopOrder::getOrdersn, mainParam)
                );
                syncParam = mainParam;
                syncType = OpCenterJobSyncTypeEnum.按照唯一标识同步.getCode();
            }
        } else {
            // 获取十五分钟前的时间
            // 获取十五分钟内变化的订单数据，实际定时任务每十分钟执行一次
            Date fifteenMinutesAgo = DateUtil.offsetMinute(new Date(), -15);
            // 数据变化量
            total = flscShopOrderMapper.selectCount(
                    Wrappers.<FlscShopOrder>lambdaQuery()
                            .ge(FlscShopOrder::getSyncTime, fifteenMinutesAgo)
            );
            syncParam = fifteenMinutesAgo;
            syncType = OpCenterJobSyncTypeEnum.默认同步.getCode();
        }

        int errorOrderCount = 0;
        int errorOrderGoodsCount = 0;
        int errorOrderMerchantTransportGoodsCount = 0;
        int batchSize = 1000;

        if (total == 0) {
            // 没有数据变动
            log.info("福利商城正单数据同步 & 运费商品构造 无数据变化");
            XxlJobHelper.log("福利商城正单数据同步 & 运费商品构造 无数据变化");
            return;
        } else if (total <= batchSize) {
            // 变动数据量小于1000
            flscShopOrderList = getOrderListBySyncType(syncType, syncParam);
            batchHandle(flscShopOrderList, errorOrderCount, errorOrderGoodsCount, errorOrderMerchantTransportGoodsCount);
        } else {
            // 变动数据量大于1000,分批次处理
            int batch = total / batchSize;
            int remainder = total % batchSize;
            int times = remainder == 0 ? batch : batch + 1;
            int offset = 0;
            for (int i = 0; i < times; i++) {
                flscShopOrderList = getOrderListBySyncTypeAndForBatch(syncType, syncParam, offset, batchSize);
                batchHandle(flscShopOrderList, errorOrderCount, errorOrderGoodsCount, errorOrderMerchantTransportGoodsCount);
                flscShopOrderList = null;
                offset += batchSize;
            }
        }


        log.info("福利商城订单&运费商品&商户承担运费商品增量同步任务执行成功, 同步类型：{}, 同步参数: {}, 开始时间:{}， 结束时间: {} 本次同步订单数量：{}, 订单总失败记录数: {}, 订单运费商品总失败记录数: {}, 订单商户承担运费商品总失败记录数： {}",
                OpCenterJobSyncTypeEnum.getDescByCode(syncType), jobParam, startTime, DateUtil.now(), total, errorOrderCount, errorOrderGoodsCount, errorOrderMerchantTransportGoodsCount);

    }

    /**
     * 批量处理
     *
     * @param flscShopOrderList
     * @param errorOrderCount
     * @param errorOrderGoodsCount
     * @param errorOrderMerchantTransportGoodsCount
     */
    private void batchHandle(List<FlscShopOrder> flscShopOrderList, int errorOrderCount, int errorOrderGoodsCount, int errorOrderMerchantTransportGoodsCount) {
        // 福利商城订单待新增列表
        List<OperationCenterOrder> operationCenterOrderInsertList = new ArrayList<>();
        // 福利商城订单待修改列表
        List<OperationCenterOrder> operationCenterOrderUpdateList = new ArrayList<>();
        // 福利商城订单运费商品待新增列表
        List<OperationCenterOrderGoods> operationCenterOrderGoodsInsertList = new ArrayList<>();
        // 福利商城订单运费商品待修改列表
        List<OperationCenterOrderGoods> operationCenterOrderGoodsUpdateList = new ArrayList<>();
        // 福利商城订单商户承担运费商品待新增列表
        List<OperationCenterOrderGoods> operationCenterOrderMerchantTransportGoodsInsertList = new ArrayList<>();
        // 福利商城订单商户承担运费商品待修改列表
        List<OperationCenterOrderGoods> operationCenterOrderMerchantTransportGoodsUpdateList = new ArrayList<>();

        if (CollectionUtil.isNotEmpty(flscShopOrderList)) {
            for (FlscShopOrder flscShopOrder : flscShopOrderList) {
                // 构造福利商城订单
                OperationCenterOrder operationCenterOrder = flscShopOrderService.buildOpCenterOrderFromFlscOrder(flscShopOrder);
                OperationCenterOrderGoods operationCenterFreightOrderGoods = null;
                OperationCenterOrderGoods opCenterOrderMerchantTransportAmountGoods = null;
                if (BigDecimal.ZERO.compareTo(flscShopOrder.getDispatchprice()) < 0) {
                    // 构造福利商城订单运费商品
                    operationCenterFreightOrderGoods = flscShopOrderService.buildOperationCenterFreightOrderGoods(flscShopOrder, operationCenterOrder);
                }
                /**
                 * 商户承担运费大于0时 需要构造商户承担运费商品
                 */
                BigDecimal merchantTransportAmount = operationCenterOrder.getMerchantTransportAmount();
                if (BigDecimal.ZERO.compareTo(merchantTransportAmount) < 0) {
                    opCenterOrderMerchantTransportAmountGoods = flscShopOrderService.buildOperationCenterMerchantFreightOrderGoods(flscShopOrder, operationCenterOrder, merchantTransportAmount);
                }

                // 判断福利商城订单是否存在
                OperationCenterOrder operationCenterOrderDB = operationCenterOrderMapper.selectOne(
                        Wrappers.<OperationCenterOrder>lambdaQuery()
                                .eq(OperationCenterOrder::getOrderSn, operationCenterOrder.getOrderSn())
                                .eq(OperationCenterOrder::getOrderBizTypeId, OpCenterOrderBizTypeEnum.订单.getCode())
                                .eq(OperationCenterOrder::getOrderTypeCode, OpCenterOrderTypeEnum.福利商城.getCode())
                                .eq(OperationCenterOrder::getBizPlatformCode, OpCenterBizPlatformEnum.福利商城.getCode())
                );
                if (operationCenterOrderDB == null || operationCenterOrderDB.getId() == null) {
                    // 福利商城订单不存在
                    operationCenterOrder = operationCenterOrder.toBuilder()
                            .createUserId("0")
                            .createUserName("增量定时任务同步")
                            .createTime(new Date())
                            .build();
                    operationCenterOrderInsertList.add(operationCenterOrder);
                } else {
                    // 福利商城订单存在
                    operationCenterOrder = operationCenterOrder.toBuilder()
                            .id(operationCenterOrderDB.getId())
                            .platformAftersaleStatusId(operationCenterOrderDB.getPlatformAftersaleStatusId())
                            .platformAftersaleType(operationCenterOrderDB.getPlatformAftersaleType())
                            .platformAftersaleStatusId(operationCenterOrderDB.getPlatformAftersaleStatusId())
                            .updateUserId("0")
                            .updateUserName("增量定时任务同步")
                            .updateTime(new Date())
                            .build();
                    operationCenterOrderUpdateList.add(operationCenterOrder);
                }

                if (operationCenterFreightOrderGoods != null) {
                    // 判断福利商城订单运费商品是否存在
                    OperationCenterOrderGoods operationCenterOrderGoodsDB = operationCenterOrderGoodsMapper.selectOne(
                            Wrappers.<OperationCenterOrderGoods>lambdaQuery()
                                    .eq(OperationCenterOrderGoods::getOrderSn, operationCenterOrder.getOrderSn())
                                    .eq(OperationCenterOrderGoods::getBizTypeId, OpCenterOrderBizTypeEnum.订单.getCode())
                                    .eq(OperationCenterOrderGoods::getOrderTypeCode, OpCenterOrderTypeEnum.福利商城.getCode())
                                    .eq(OperationCenterOrderGoods::getBizPlatformCode, OpCenterBizPlatformEnum.福利商城.getCode())
                                    .eq(OperationCenterOrderGoods::getOrderGoodsId, OpCenterOrderTypeEnum.福利商城.getCode() + "_" + OpCenterGoodsTypeEnum.运费.getPrefix() + flscShopOrder.getId())// 订单商品id 运费id构造：FLSC_YF订单id
                    );
                    if (operationCenterOrderGoodsDB == null || operationCenterOrderGoodsDB.getId() == null) {
                        // 福利商城订单运费商品不存在
                        operationCenterFreightOrderGoods = operationCenterFreightOrderGoods.toBuilder()
                                .createUserId("0")
                                .createUserName("增量定时任务同步")
                                .createTime(new Date())
                                .build();
                        operationCenterOrderGoodsInsertList.add(operationCenterFreightOrderGoods);
                    } else {
                        // 福利商城订单运费商品存在
                        operationCenterFreightOrderGoods = operationCenterFreightOrderGoods.toBuilder()
                                .id(operationCenterOrderGoodsDB.getId())
                                .updateUserId("0")
                                .updateUserName("增量定时任务同步")
                                .updateTime(new Date())
                                .build();
                        operationCenterOrderGoodsUpdateList.add(operationCenterFreightOrderGoods);
                    }
                }
                // 判断福利商城订单商户承担运费商品是否存在
                if (opCenterOrderMerchantTransportAmountGoods != null) {
                    OperationCenterOrderGoods operationCenterOrderMerchantTransportGoodsDB = operationCenterOrderGoodsMapper.selectOne(
                            Wrappers.<OperationCenterOrderGoods>lambdaQuery()
                                    .eq(OperationCenterOrderGoods::getOrderSn, operationCenterOrder.getOrderSn())
                                    .eq(OperationCenterOrderGoods::getBizTypeId, OpCenterOrderBizTypeEnum.订单.getCode())
                                    .eq(OperationCenterOrderGoods::getOrderTypeCode, OpCenterOrderTypeEnum.福利商城.getCode())
                                    .eq(OperationCenterOrderGoods::getBizPlatformCode, OpCenterBizPlatformEnum.福利商城.getCode())
                                    .eq(OperationCenterOrderGoods::getOrderGoodsId, OpCenterOrderTypeEnum.福利商城.getCode() + "_" + OpCenterGoodsTypeEnum.商户承担运费.getPrefix() + flscShopOrder.getId())// 订单商品id 运费id构造：FLSC_SHYF订单id
                    );
                    if (operationCenterOrderMerchantTransportGoodsDB == null || operationCenterOrderMerchantTransportGoodsDB.getId() == null) {
                        // 福利商城订单商户承担运费商品不存在
                        opCenterOrderMerchantTransportAmountGoods = opCenterOrderMerchantTransportAmountGoods.toBuilder()
                                .createUserId("0")
                                .createUserName("增量定时任务同步")
                                .createTime(new Date())
                                .build();
                        operationCenterOrderMerchantTransportGoodsInsertList.add(opCenterOrderMerchantTransportAmountGoods);
                    } else {
                        // 福利商城订单商户承担运费商品存在
                        opCenterOrderMerchantTransportAmountGoods = opCenterOrderMerchantTransportAmountGoods.toBuilder()
                                .id(operationCenterOrderMerchantTransportGoodsDB.getId())
                                .updateUserId("0")
                                .updateUserName("增量定时任务同步")
                                .updateTime(new Date())
                                .build();
                        operationCenterOrderMerchantTransportGoodsUpdateList.add(opCenterOrderMerchantTransportAmountGoods);
                    }
                }
            }
        }

        if (CollectionUtil.isNotEmpty(operationCenterOrderInsertList)) {
            for (OperationCenterOrder operationCenterOrder : operationCenterOrderInsertList) {
                // 循环插入福利商城订单
                try {
                    operationCenterOrderMapper.insert(operationCenterOrder);
                } catch (Exception e) {
                    // 异常数据需要记录在表
                    ThreadUtil.execute(() -> {
                        operationDataSyncErrorRecordService.save(
                                OperationDataSyncErrorRecord.builder()
                                        .syncType(OperationDataSyncTypeEnum.订单.getName())
                                        .bizPlatformCode(OpCenterBizPlatformEnum.福利商城.getCode())
                                        .bizPlatformName(OpCenterBizPlatformEnum.福利商城.getName())
                                        .mainParam(String.valueOf(operationCenterOrder.getBizOrderId()))
                                        .orderSn(operationCenterOrder.getOrderSn())
                                        .syncTime(new Date())
                                        .errMsg("订单新增失败：" + JSON.toJSONString(e))
                                        .retentionData(JSON.toJSONString(operationCenterOrder))
                                        .handleStatus(OperationDataSyncErrorHandleStatusEnum.未处理.getCode())
                                        .build()
                        );
                    });
                    log.info("福利商城订单插入失败, 订单号: {}", operationCenterOrder.getOrderSn(), e);
                    XxlJobHelper.log("福利商城订单插入失败, 订单号: {}", operationCenterOrder.getOrderSn());
                    errorOrderCount++;
                }
            }
        }
        if (CollectionUtil.isNotEmpty(operationCenterOrderUpdateList)) {
            for (OperationCenterOrder operationCenterOrder : operationCenterOrderUpdateList) {
                // 循环更新福利商城订单
                try {
                    operationCenterOrderMapper.updateById(operationCenterOrder);
                } catch (Exception e) {
                    // 异常数据需要记录在表
                    ThreadUtil.execute(() -> {
                        operationDataSyncErrorRecordService.save(
                                OperationDataSyncErrorRecord.builder()
                                        .syncType(OperationDataSyncTypeEnum.订单.getName())
                                        .bizPlatformCode(OpCenterBizPlatformEnum.福利商城.getCode())
                                        .bizPlatformName(OpCenterBizPlatformEnum.福利商城.getName())
                                        .mainParam(String.valueOf(operationCenterOrder.getBizOrderId()))
                                        .orderSn(operationCenterOrder.getOrderSn())
                                        .syncTime(new Date())
                                        .errMsg("订单修改失败：" + JSON.toJSONString(e))
                                        .retentionData(JSON.toJSONString(operationCenterOrder))
                                        .handleStatus(OperationDataSyncErrorHandleStatusEnum.未处理.getCode())
                                        .build()
                        );
                    });
                    log.info("福利商城订单更新失败, 订单号: {}", operationCenterOrder.getOrderSn(), e);
                    XxlJobHelper.log("福利商城订单更新失败, 订单号: {}", operationCenterOrder.getOrderSn());
                    errorOrderCount++;
                }
            }
        }

        if (CollectionUtil.isNotEmpty(operationCenterOrderGoodsInsertList)) {
            for (OperationCenterOrderGoods operationCenterOrderGoods : operationCenterOrderGoodsInsertList) {
                // 循环插入福利商城订单运费商品
                try {
                    operationCenterOrderGoodsMapper.insert(operationCenterOrderGoods);
                } catch (Exception e) {
                    // 异常数据需要记录在表
                    ThreadUtil.execute(() -> {
                        operationDataSyncErrorRecordService.save(
                                OperationDataSyncErrorRecord.builder()
                                        .syncType(OperationDataSyncTypeEnum.订单商品.getName())
                                        .bizPlatformCode(OpCenterBizPlatformEnum.福利商城.getCode())
                                        .bizPlatformName(OpCenterBizPlatformEnum.福利商城.getName())
                                        .mainParam(String.valueOf(operationCenterOrderGoods.getOrderGoodsId()))
                                        .orderSn(operationCenterOrderGoods.getOrderSn())
                                        .orderGoodsId(operationCenterOrderGoods.getOrderGoodsId())
                                        .syncTime(new Date())
                                        .errMsg("订单运费商品新增失败: " + JSON.toJSONString(e))
                                        .retentionData(JSON.toJSONString(operationCenterOrderGoods))
                                        .handleStatus(OperationDataSyncErrorHandleStatusEnum.未处理.getCode())
                                        .build()
                        );
                    });
                    log.info("福利商城订单运费商品插入失败, 订单号: {}", operationCenterOrderGoods.getOrderSn(), e);
                    XxlJobHelper.log("福利商城订单运费商品插入失败, 订单号: {}", operationCenterOrderGoods.getOrderSn());
                    errorOrderGoodsCount++;
                }
            }
        }

        if (CollectionUtil.isNotEmpty(operationCenterOrderGoodsUpdateList)) {
            for (OperationCenterOrderGoods operationCenterOrderGoods : operationCenterOrderGoodsUpdateList) {
                // 循环更新福利商城订单运费商品
                try {
                    operationCenterOrderGoodsMapper.updateById(operationCenterOrderGoods);
                } catch (Exception e) {
                    // 异常数据需要记录在表
                    ThreadUtil.execute(() -> {
                        operationDataSyncErrorRecordService.save(
                                OperationDataSyncErrorRecord.builder()
                                        .syncType(OperationDataSyncTypeEnum.订单商品.getName())
                                        .bizPlatformCode(OpCenterBizPlatformEnum.福利商城.getCode())
                                        .bizPlatformName(OpCenterBizPlatformEnum.福利商城.getName())
                                        .mainParam(String.valueOf(operationCenterOrderGoods.getOrderGoodsId()))
                                        .orderSn(operationCenterOrderGoods.getOrderSn())
                                        .orderGoodsId(operationCenterOrderGoods.getOrderGoodsId())
                                        .syncTime(new Date())
                                        .errMsg("订单运费商品修改失败: " + JSON.toJSONString(e))
                                        .retentionData(JSON.toJSONString(operationCenterOrderGoods))
                                        .handleStatus(OperationDataSyncErrorHandleStatusEnum.未处理.getCode())
                                        .build()
                        );
                    });
                    log.info("福利商城订单运费商品更新失败, 订单号: {}", operationCenterOrderGoods.getOrderSn(), e);
                    XxlJobHelper.log("福利商城订单运费商品更新失败, 订单号: {}", operationCenterOrderGoods.getOrderSn());
                    errorOrderGoodsCount++;
                }
            }
        }
        if (CollectionUtil.isNotEmpty(operationCenterOrderMerchantTransportGoodsInsertList)) {
            for (OperationCenterOrderGoods operationCenterOrderGoods : operationCenterOrderMerchantTransportGoodsInsertList) {
                try {
                    operationCenterOrderGoodsMapper.insert(operationCenterOrderGoods);
                } catch (Exception e) {
                    // 异常数据需要记录在表
                    ThreadUtil.execute(() -> {
                        operationDataSyncErrorRecordService.save(
                                OperationDataSyncErrorRecord.builder()
                                        .syncType(OperationDataSyncTypeEnum.订单商品.getName())
                                        .bizPlatformCode(OpCenterBizPlatformEnum.福利商城.getCode())
                                        .bizPlatformName(OpCenterBizPlatformEnum.福利商城.getName())
                                        .mainParam(String.valueOf(operationCenterOrderGoods.getOrderGoodsId()))
                                        .orderSn(operationCenterOrderGoods.getOrderSn())
                                        .orderGoodsId(operationCenterOrderGoods.getOrderGoodsId())
                                        .syncTime(new Date())
                                        .errMsg("订单商户承担运费商品新增失败: " + JSON.toJSONString(e))
                                        .retentionData(JSON.toJSONString(operationCenterOrderGoods))
                                        .handleStatus(OperationDataSyncErrorHandleStatusEnum.未处理.getCode())
                                        .build()
                        );
                    });
                    log.info("福利商城订单商户承担运费商品新增失败, 订单号: {}", operationCenterOrderGoods.getOrderSn(), e);
                    XxlJobHelper.log("福利商城订单商户承担运费商品新增失败, 订单号: {}", operationCenterOrderGoods.getOrderSn());
                    errorOrderMerchantTransportGoodsCount++;
                }
            }
        }

        if (CollectionUtil.isNotEmpty(operationCenterOrderMerchantTransportGoodsUpdateList)) {
            for (OperationCenterOrderGoods operationCenterOrderGoods : operationCenterOrderMerchantTransportGoodsUpdateList) {
                try {
                    operationCenterOrderGoodsMapper.updateById(operationCenterOrderGoods);
                } catch (Exception e) {
                    // 异常数据需要记录在表
                    ThreadUtil.execute(() -> {
                        operationDataSyncErrorRecordService.save(
                                OperationDataSyncErrorRecord.builder()
                                        .syncType(OperationDataSyncTypeEnum.订单商品.getName())
                                        .bizPlatformCode(OpCenterBizPlatformEnum.福利商城.getCode())
                                        .bizPlatformName(OpCenterBizPlatformEnum.福利商城.getName())
                                        .mainParam(String.valueOf(operationCenterOrderGoods.getOrderGoodsId()))
                                        .orderSn(operationCenterOrderGoods.getOrderSn())
                                        .orderGoodsId(operationCenterOrderGoods.getOrderGoodsId())
                                        .syncTime(new Date())
                                        .errMsg("订单商户承担运费商品更新失败: " + JSON.toJSONString(e))
                                        .retentionData(JSON.toJSONString(operationCenterOrderGoods))
                                        .handleStatus(OperationDataSyncErrorHandleStatusEnum.未处理.getCode())
                                        .build()
                        );
                    });
                    log.info("福利商城订单商户承担运费商品更新失败, 订单号: {}", operationCenterOrderGoods.getOrderSn(), e);
                    XxlJobHelper.log("福利商城订单商户承担运费商品更新失败, 订单号: {}", operationCenterOrderGoods.getOrderSn());
                    errorOrderMerchantTransportGoodsCount++;
                }
            }
        }

    }

    /**
     * 根据不同的同步类型获取订单列表
     *
     * @param syncType
     * @param syncParam
     * @return
     */
    private List<FlscShopOrder> getOrderListBySyncType(int syncType, Object syncParam) {
        // 根据不同的同步类型获取订单列表
        switch (syncType) {
            case 2:
                // 按照唯一标识同步
                return flscShopOrderMapper.selectList(
                        Wrappers.<FlscShopOrder>lambdaQuery()
                                .eq(FlscShopOrder::getOrdersn, syncParam)
                );
            default:
                // 默认同步 & 按照指定时间同步 通用此方法
                return flscShopOrderMapper.selectList(
                        Wrappers.<FlscShopOrder>lambdaQuery()
                                .ge(FlscShopOrder::getSyncTime, syncParam)
                );
        }
    }

    /**
     * 根据不同的同步类型获取订单 & 分批获取
     *
     * @param syncType
     * @param syncParam
     * @param offset
     * @param batchSize
     * @return
     */
    private List<FlscShopOrder> getOrderListBySyncTypeAndForBatch(int syncType, Object syncParam, int offset, int batchSize) {
        switch (syncType) {
            case 2:
                // 按照唯一标识同步
                return flscShopOrderMapper.selectList(
                        Wrappers.<FlscShopOrder>lambdaQuery()
                                .eq(FlscShopOrder::getOrdersn, syncParam)
                                .last("limit " + offset + "," + batchSize)
                );
            default:
                // 默认同步 & 按照指定时间同步 通用此方法
                return flscShopOrderMapper.selectList(
                        Wrappers.<FlscShopOrder>lambdaQuery()
                                .ge(FlscShopOrder::getSyncTime, syncParam)
                                .last("limit " + offset + "," + batchSize)
                );
        }
    }
}
